==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/messages/pl/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Potwierdź</strong> Akcje',
    '<strong>Latest</strong> updates' => '<strong>Najnowsze</strong> aktualizacje',
    '<strong>Mail</strong> summary' => '<strong>Mail</strong> podsumowanie',
    'Account settings' => 'Ustawienia konta',
    'Actions' => 'Akcje',
    'Add:' => 'Dodaj:',
    'Administration' => 'Administracja',
    'All' => 'Wszystkie',
    'Allow' => 'Zezwól',
    'An error occurred while handling your last action. (Handler not found).' => 'Wystąpił błąd podczas wykonywania ostatniej czynności. (Handler not found).',
    'An unexpected error occurred while loading the search result.' => 'Wystąpił nieoczekiwany błąd podczas ładowania wyników wyszukiwania.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Wystąpił nieoczekiwany błąd. Jeśli problem będzie się powtarzał, skontaktuj się z administratorem strony.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Wystąpił nieoczekiwany błąd serwera. Jeśli problem będzie się powtarzał, skontaktuj się z administratorem strony.',
    'An unknown error occurred while uploading.' => 'Wystąpił nieznany błąd podczas ładowania.',
    'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Wystąpił nieznany błąd podczas ładowania.  Podpowiedź: sprawdź ustawienia upload_max_filesize i post_max_size php.',
    'Back' => 'Wstecz',
    'Back to dashboard' => 'Powrót do pulpitu',
    'Cancel' => 'Anuluj',
    'Choose language:' => 'Wybierz język:',
    'Close' => 'Zamknij',
    'Collapse' => 'Zwiń',
    'Confirm' => 'Potwierdź',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Źródło zawartości dodatku musi być instancją HActiveRecordContent lub HActiveRecordContentAddon!',
    'Copy to clipboard' => 'Kopiuj do schowka',
    'Could not find content of addon!' => 'Nie znaleziono zawartości dodatku!',
    'Could not find requested page.' => 'Nie znaleziono strony.',
    'Default' => 'Domyślny',
    'Delete' => 'Usuń',
    'Deny' => 'Odmów',
    'Do you really want to perform this action?' => 'Czy na pewno chcesz wykonać tę czynność?',
    'Edit' => 'Edytuj',
    'Error' => 'Błąd',
    'Error while running your last action (Invalid request method).' => 'Wystapił błąd podczasy wykonania ostatniej czynności (Nieprawidłowa metoda żądania).',
    'Error:' => 'Błąd:',
    'Expand' => 'Rozwiń',
    'Export' => 'Eksportuj',
    'Info:' => 'Info:',
    'Invalid request method!' => 'Błędna metoda żądania!',
    'It looks like you may have taken the wrong turn.' => 'Chyba zabłądziłeś.',
    'Language' => 'Język',
    'Loading...' => 'Ładowanie...',
    'Login' => 'Zaloguj',
    'Logo of {appName}' => 'Logo {appName}',
    'Logout' => 'Wyloguj',
    'Menu' => 'Menu',
    'Module is not enabled on this content container!' => 'Moduł w tym kontenerze nie jest aktywny!',
    'My profile' => 'Mój profil',
    'New profile image' => 'Nowe zdjęcie profilowe',
    'Next' => 'Dalej',
    'No error information given.' => 'Nie podano informacji o błędzie.',
    'Oooops...' => 'Upsss...',
    'Open' => 'Otwórz',
    'Please type at least 3 characters' => 'Wpisz przynajmniej 3 znaki',
    'Please type at least {count} characters' => 'Wpisz przynajmniej {count} znaki',
    'Powered by {name}' => 'Od {name}',
    'Profile dropdown' => 'Rozwiń Profil',
    'Profile picture of {displayName}' => 'Zdjęcie profilowe {displayName}',
    'Save' => 'Zapisz',
    'Saved' => 'Zapisano',
    'Search' => 'Szukaj',
    'Select Me' => 'Wybierz mnie',
    'Show less' => 'Pokaż mniej',
    'Show more' => 'Pokaż więcej',
    'Some files could not be uploaded:' => 'Niektóre pliki nie mogą zostać przesłane:',
    'Stop impersonation' => 'Zatrzymaj podszywanie się',
    'Text could not be copied to clipboard' => 'Tekst nie mógł zostać skopiowany do schowka',
    'Text has been copied to clipboard' => 'Tekst został skopiowany do schowka',
    'The date has to be in the past.' => 'Wpisana data musi być wcześniejsza.',
    'The file has been deleted.' => 'Plik został usunięty.',
    'The requested resource could not be found.' => 'Żądany zasób nie został znaleziony.',
    'The space has been archived.' => 'Strefa ma zostać zarchiwizowana.',
    'The space has been unarchived.' => 'Strefa ma zostać rozpakowana.',
    'Time Zone' => 'Strefa czasowa',
    'Toggle comment menu' => 'Przełącz menu komentarzy',
    'Toggle panel menu' => 'Przełącz menu panela',
    'Toggle post menu' => 'Przełącz menu wpisów',
    'Toggle stream entry menu' => 'Przełącz menu wpisu źródła',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Istnieją niezapisane zmiany, na pewno chcesz opuścić tę stronę?',
    'Unsubscribe' => 'Anuluj subskrybcję',
    'Upload' => 'Prześlij',
    'Upload file' => 'Prześlij plik',
    'You are not allowed to run this action.' => 'Nie posiadasz uprawnień do wykonania tej czynności.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/messages/pl/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Potwierdź</strong> Akcje',
    '<strong>Latest</strong> updates' => '<strong>Najnowsze</strong> aktualizacje',
    '<strong>Mail</strong> summary' => '<strong>Mail</strong> podsumowanie',
    'Actions' => 'Akcje',
    'Add:' => 'Dodaj:',
    'Administration' => 'Administracja',
    'All' => 'Wszystkie',
    'Allow' => 'Zezwól',
    'Allow content from external source' => 'Pozwól na treści z zewnętrznego źródła',
    'Always allow content from this provider!' => 'Zawsze pozwalaj na treści od tego dostawcy!',
    'An error occurred while handling your last action. (Handler not found).' => 'Wystąpił błąd podczas wykonywania ostatniej czynności. (Handler not found).',
    'An unexpected error occurred while loading the search result.' => 'Wystąpił nieoczekiwany błąd podczas ładowania wyników wyszukiwania.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Wystąpił nieoczekiwany błąd. Jeśli problem będzie się powtarzał, skontaktuj się z administratorem strony.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Wystąpił nieoczekiwany błąd serwera. Jeśli problem będzie się powtarzał, skontaktuj się z administratorem strony.',
    'Back' => 'Wstecz',
    'Back to dashboard' => 'Powrót do pulpitu',
    'Cancel' => 'Anuluj',
    'Choose language:' => 'Wybierz język:',
    'Close' => 'Zamknij',
    'Collapse' => 'Zwiń',
    'Confirm' => 'Potwierdź',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Źródło zawartości dodatku musi być instancją HActiveRecordContent lub HActiveRecordContentAddon!',
    'Copy to clipboard' => 'Kopiuj do schowka',
    'Could not find content of addon!' => 'Nie znaleziono zawartości dodatku!',
    'Could not find requested page.' => 'Nie znaleziono strony.',
    'Default' => 'Domyślny',
    'Delete' => 'Usuń',
    'Deny' => 'Odmów',
    'Do you really want to perform this action?' => 'Czy na pewno chcesz wykonać tę czynność?',
    'Do you want to enable content from \'{urlPrefix}\'?' => 'Czy chcesz zezwolić na treści od \'{urlPrefix}\'?',
    'Edit' => 'Edytuj',
    'Error' => 'Błąd',
    'Error while running your last action (Invalid request method).' => 'Wystapił błąd podczasy wykonania ostatniej czynności (Nieprawidłowa metoda żądania).',
    'Error:' => 'Błąd:',
    'Expand' => 'Rozwiń',
    'Export' => 'Eksportuj',
    'Info:' => 'Info:',
    'Invalid request method!' => 'Błędna metoda żądania!',
    'It looks like you may have taken the wrong turn.' => 'Chyba zabłądziłeś.',
    'Language' => 'Język',
    'Loading...' => 'Ładowanie...',
    'Login' => 'Zaloguj',
    'Logo of {appName}' => 'Logo {appName}',
    'Logout' => 'Wyloguj',
    'Menu' => 'Menu',
    'Module is not enabled on this content container!' => 'Moduł w tym kontenerze nie jest aktywny!',
    'New profile image' => 'Nowe zdjęcie profilowe',
    'Next' => 'Dalej',
    'No error information given.' => 'Nie podano informacji o błędzie.',
    'Oooops...' => 'Upsss...',
    'Open' => 'Otwórz',
    'Please type at least 3 characters' => 'Wpisz przynajmniej 3 znaki',
    'Please type at least {count} characters' => 'Wpisz przynajmniej {count} znaki',
    'Powered by {name}' => 'Od {name}',
    'Profile dropdown' => 'Rozwiń Profil',
    'Profile picture of {displayName}' => 'Zdjęcie profilowe {displayName}',
    'Save' => 'Zapisz',
    'Saved' => 'Zapisano',
    'Search' => 'Szukaj',
    'Search...' => 'Szukaj...',
    'Select Me' => 'Wybierz mnie',
    'Settings' => 'Ustawienia',
    'Show less' => 'Pokaż mniej',
    'Show more' => 'Pokaż więcej',
    'Some files could not be uploaded:' => 'Niektóre pliki nie mogą zostać przesłane:',
    'Stop impersonation' => 'Zatrzymaj podszywanie się',
    'Text could not be copied to clipboard' => 'Tekst nie mógł zostać skopiowany do schowka',
    'Text has been copied to clipboard' => 'Tekst został skopiowany do schowka',
    'The date has to be in the past.' => 'Wpisana data musi być wcześniejsza.',
    'The file has been deleted.' => 'Plik został usunięty.',
    'The requested resource could not be found.' => 'Żądany zasób nie został znaleziony.',
    'The space has been archived.' => 'Strefa ma zostać zarchiwizowana.',
    'The space has been unarchived.' => 'Strefa ma zostać rozpakowana.',
    'Time Zone' => 'Strefa czasowa',
    'Toggle comment menu' => 'Przełącz menu komentarzy',
    'Toggle panel menu' => 'Przełącz menu panela',
    'Toggle post menu' => 'Przełącz menu wpisów',
    'Toggle stream entry menu' => 'Przełącz menu wpisu źródła',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Istnieją niezapisane zmiany, na pewno chcesz opuścić tę stronę?',
    'Unsubscribe' => 'Anuluj subskrybcję',
    'Upload' => 'Prześlij',
    'Upload file' => 'Prześlij plik',
    'You are not allowed to run this action.' => 'Nie posiadasz uprawnień do wykonania tej czynności.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'My Profile' => '',
    'No results' => '',
    'Show all results' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
];
